<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>WLAN ein</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>WLAN aus</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Feststelltaste ein</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Feststelltaste aus</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Ziffernblock ein</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Ziffernblock aus</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Touchpad ein</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Touchpad aus</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Tastfeld-Umschalter</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Fn-Umschalter</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Flugzeugmodus ein</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Flugzeugmodus aus</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Ausgeglichene Leistung</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Energiesparen</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Hohe Leistung</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Fenstereffekt aktiviert</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Fenstereffekt deaktiviert</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Fehler beim Aktivieren der Fenstereffekte</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Microphone on</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>